//@line 36 "/builds/tinderbox/Tb-Mozilla1.8-l10n/Linux_2.4.20-28.8_Clobber/mozilla/mail/locales/../../../l10n/pa-IN/mail/all-l10n.js"

//@line 38 "/builds/tinderbox/Tb-Mozilla1.8-l10n/Linux_2.4.20-28.8_Clobber/mozilla/mail/locales/../../../l10n/pa-IN/mail/all-l10n.js"

pref("general.useragent.locale", "pa-IN");
